@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub new {
     my ($class) = @_;
@@ -130,7 +130,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 SYNOPSIS
 
@@ -140,10 +140,10 @@ Check the security of your TLS services
 
     my $labs = WebService::SSLLabs->new();
     my $host;
-    while(not $host = $labs->analyze(host => 'ssllabs.com')->done()) {
+    while(not $host = $labs->analyze(host => 'ssllabs.com')->complete()) {
         sleep 10;
     }
-    if ($host->status() eq 'READY') {
+    if ($host->ready()) {
        foreach my $endpoint ($host->endpoints()) {
            say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
        }
