@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Endpoint();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -19,7 +19,17 @@ sub new {
     return $self;
 }
 
-sub done {
+sub ready {
+    my ($self) = @_;
+    if ( $self->status() =~ /^READY$/smxi ) {
+        return $self;
+    }
+    else {
+        return;
+    }
+}
+
+sub complete {
     my ($self) = @_;
     if ( $self->status() =~ /^READY|ERROR$/smxi ) {
         return $self;
@@ -93,7 +103,7 @@ WebService::SSLLabs::Host - Host object
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 SUBROUTINES/METHODS
 
@@ -101,9 +111,14 @@ Version 0.13
 
 a new C<WebService::SSLLabs::Host> object, accepts a hash ref as it's parameter.
 
-=head2 done
+=head2 complete
 
-will return the current C<WebService::SSLLabs::Host> object if L<status|WebService::SSLLabs::Host/"status"> is equal to READY or ERROR.  Otherwise it will return undef.
+will return the current C<WebService::SSLLabs::Host> object if L<status|WebService::SSLLabs::Host/"status"> is READY or ERROR. Otherwise it will return undef
+assessment status; possible values: DNS, ERROR, IN_PROGRESS, and READY.
+
+=head2 ready
+
+will return the current C<WebService::SSLLabs::Host> object if L<status|WebService::SSLLabs::Host/"status"> is equal to READY.  Otherwise it will return undef.
 
 =head2 host 
 
@@ -139,7 +154,7 @@ assessment completion time, in milliseconds since 1970
 
 =head2 engine_version
 
-assessment engine version (e.g., "1.0.130")
+assessment engine version (e.g., "1.0.140")
 
 =head2 criteria_version
 
